<?php
require_once 'suggestions_provider.php';

/**
 * Suggestions provider for Gismeteo cities.
 *
 * Exmaple of usage:
 * <pre>
 * $advKeys = new AdvKeyboard($parent_media_url, $plugin_cookies, $this, 'gismeteo_cityId');
 * $advKeys->suggestionsProvider = new GismeteoSuggestionsProvider($guiLanguageCode);
 * $advKeys->minLengthForSuggestions = 2;
 * $advKeys->searchAndSelectMode = true;
 * return $advKeys->startup_kbrd();
 * </pre>
 */
class GismeteoSuggestionsProvider implements SuggestionsProvider
{

    private $lang;

    public function __construct($lang = null)
    {
        if ($lang == 'ru') {
            $lang = null;
        } elseif ($lang != 'ua' && $lang != 'de' && $lang != 'en') {
            $lang = 'en';
        }
        $this->lang = $lang;
    }

    public function getSuggestions($query)
    {
        $sugg = array();
        if ($query != '') {
            $query = rawurlencode($query);
            $sugg = json_decode(HD::http_get_document("https://www.gismeteo.ru/api/v2/search/searchresultforsuggest/{$query}/?type=all" . ($this->lang ? "&lang=" . $this->lang : "")));
            if (isset($sugg->items)) {
                $sugg = $sugg->items;
            }
        }
        return $sugg;
    }

    public function getSuggestionView($suggestion, $textColor)
    {
        $text = $suggestion->name;
        $text2 = "<gap width=\"10\"/><text color=\"7\">(";
        if (isset($suggestion->district))
            $text2 .= $suggestion->district->name . ", ";
        $text2 .= $suggestion->country->name . ")</text>";
        $icon = "";
        if (isset($suggestion->country->code)) {
            $iconFile = DuneSystem::$properties['install_dir_path'] . "/icons/flags/" . strtolower($suggestion->country->code) . ".png";
            if (file_exists($iconFile)) {
                $icon = "<icon>" . $iconFile . "</icon><gap width=\"10\"/>";
            }
        }
        if (! $icon) {
            $icon = "<gap width=\"58\"/>";
        }
        $str = $icon . "<text color=\"$textColor\">$text</text>$text2";
        return $str;
    }

    public function getSearchText($suggestion)
    {
        return $suggestion->name;
    }

    public function getActionParameters($suggestion)
    {
        $cityNames = array();
        if (isset($suggestion->names)) {
            if (isset($suggestion->names->en)) {
                $cityNames['en'] = $suggestion->names->en;
            } else {
                $cityNames['en'] = $suggestion->name;
            }
            if (isset($suggestion->names->de)) {
                $cityNames['de'] = $suggestion->names->de;
            }
            if (isset($suggestion->names->ru)) {
                $cityNames['ru'] = $suggestion->names->ru;
            }
            if (isset($suggestion->names->ua)) {
                $cityNames['ua'] = $suggestion->names->ua;
            }
        }
        return array(
            'gismeteo_cityId' => $suggestion->id,
            'gismeteo_cityNames' => Settings::arrayToString($cityNames)
        );
    }

    public function isSearchBySuggestionOnly($suggestion)
    {
        return true;
    }
}

?>