<?php
require_once 'suggestions_provider.php';

/**
 * Suggestions provider for films and people on kinopoisk.
 *
 * Exmaple of usage:
 * <pre>
 * $advKeys = new AdvKeyboard($parent_media_url, $plugin_cookies, $this, 'do_search');
 * $advKeys->suggestionsProvider = new KinopoiskSuggestionsProvider(isset($media_url->name) && ($media_url->name == 'people'));
 * $advKeys->strRed = $search_text;
 * return $advKeys->startup_kbrd();
 * </pre>
 */
class KinopoiskSuggestionsProvider implements SuggestionsProvider
{

    const enc = 'UTF-8';

    private $people;

    public function __construct($people = false)
    {
        $this->people = $people;
    }

    public function getSuggestions($query)
    {
        $sugg = array();
        if ($query != '') {
            $otps[CURLOPT_HTTPHEADER] = array(
                'Accept: application/json',
                'Accept-Encoding: gzip, deflate, br',
                'Accept-Language: ru,uk;q=0.9,en-US;q=0.8,en;q=0.7',
                'Connection: keep-alive',
                'Content-Type: application/json',
                'Host: www.kinopoisk.ru',
                'Referer: https://www.kinopoisk.ru/',
                'User-Agent: Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/67.0.3396.87 Safari/537.36 OPR/54.0.2952.41',
                'X-Requested-With: XMLHttpRequest'
            );
            $sugg = json_decode(HD::http_get_document("https://www.kinopoisk.ru/handler_search.php?q=" . urlencode($query) . "&topsuggest=true&ajax=1", $otps));
            if (isset($sugg->captcha)) {
                return array();
            }
            if ($this->people) {
                foreach ($sugg as $k => $v)
                    if (! preg_match('|name|', $v->link))
                        unset($sugg[$k]);
                $sugg = array_values($sugg);
            }
        }
        return $sugg;
    }

    public function getSuggestionView($suggestion, $textColor)
    {
        $strTmp = null;
        if (isset($suggestion->rus)) {
            $text = HD::str_remove_tag($suggestion->rus);
            $text2name = $text2 = '';
            $textLen = mb_strlen($text, self::enc);
            if ($textLen > 42)
                $text = mb_strimwidth($text, 0, 42, "...", self::enc);
            if (($textLen < 30) && ($suggestion->name != ''))
                $text2name = HD::str_remove_tag($suggestion->name);
            if ((isset($suggestion->year)) && ($suggestion->year != '')) {
                if ($text2name != '')
                    $text2name .= ', ';
                $text2name .= HD::str_remove_tag($suggestion->year);
            }
            $text2 .= "<gap width=\"10\"/><text color=\"7\">(" . $text2name . ')</text>';
            if ((isset($suggestion->ur_rating)) && ($suggestion->ur_rating != 0))
                $text2 .= "<gap width=\"10\"/><icon>" . DuneSystem::$properties['install_dir_path'] . "/icons/kp.png</icon><gap width=\"10\"/><text color=\"7\">" . HD::str_remove_tag($suggestion->ur_rating) . '</text>';

            $ico = 'user';
            if (preg_match('|film|', $suggestion->link))
                $ico = 'v_search';
            $strTmp = "<icon>" . DuneSystem::$properties['install_dir_path'] . "/icons/$ico.png</icon><gap width=\"10\"/><text color=\"$textColor\">$text</text>$text2";
        }
        return $strTmp;
    }

    public function getSearchText($suggestion)
    {
        return $suggestion->rus;
    }

    public function getActionParameters($suggestion)
    {
        $params = array();
        if (preg_match('|film|', $suggestion->link))
            $params['open_item'] = $suggestion->id;
        else
            $params['open_people'] = $suggestion->id;
        return $params;
    }

    public function isSearchBySuggestionOnly($suggestion)
    {
        return ! preg_match('|film|', $suggestion->link);
    }
}

?>