<?php

interface SuggestionsProvider
{

    /**
     * Returns an array of suggestion items to be shown in adv keyboard.
     *
     * @param string $query
     *            Search query text.
     * @return array Suggestion items.
     */
    public function getSuggestions($query);

    /**
     * Returns styled textual representation of passed suggestion item.
     *
     * @param mixed $suggestion
     *            Suggestion item.
     * @param integer $textColor
     *            Color for main text of the text.
     * @return string Styled textual representation of passed suggestion item.
     */
    public function getSuggestionView($suggestion, $textColor);

    /**
     * Returns search query text for passed suggestion item.
     *
     * @param mixed $suggestion
     *            Suggestion item.
     * @return string Search query text for passed suggestion item.
     */
    public function getSearchText($suggestion);

    /**
     * Returns an array with additional parameters for search action triggered by passed suggestion item.
     *
     * @param mixed $suggestion
     *            Suggestion item.
     * @return array Additional parameters for search actions.
     */
    public function getActionParameters($suggestion);

    /**
     * Checks whether passed suggestion item can only trigger a final search action and can't produce searxh query.
     *
     * @param mixed $suggestion
     *            Suggestion item.
     * @return boolean True if passed suggestion item can only trigger a final search action.
     */
    public function isSearchBySuggestionOnly($suggestion);
}

class DummySuggestionsProvider implements SuggestionsProvider
{

    public function getSuggestions($query)
    {
        return array();
    }

    public function getSuggestionView($suggestion, $textColor)
    {
        return null;
    }

    public function getSearchText($suggestion)
    {
        return null;
    }

    public function getActionParameters($suggestion)
    {
        return null;
    }

    public function isSearchBySuggestionOnly($suggestion)
    {
        return false;
    }
}
?>