<?php
require_once 'suggestions_provider.php';

/**
 * Suggestions provider for youtube search queries.
 *
 * Exmaple of usage:
 * <pre>
 * $advKeys = new AdvKeyboard($media_url, $plugin_cookies, $this, 'run_search');
 * $ylb_api_key = Youtube::get_ylb_api_key();
 * $advKeys->suggestionsProvider = new YoutubeSuggestionsProvider($ylb_api_key['cr'], $ylb_api_key['hl']);
 * $advKeys->strRed = $search_text;
 * return $advKeys->startup_kbrd();
 * </pre>
 */
class YoutubeSuggestionsProvider implements SuggestionsProvider
{

    const enc = 'UTF-8';

    private $coutry;

    private $lang;

    private $site;

    public function __construct($country = 'ru', $lang = 'ru')
    {
        $this->coutry = $country;
        $this->lang = $lang;
    }

    public function getSuggestions($query)
    {
        $sugg = array();
        if ($query != '') {
            $query = rawurlencode($query);
            $doc = HD::http_get_document("http://suggestqueries.google.com/complete/search?client=toolbar&hl={$this->lang}&gl={$this->coutry}&ds=yt&q={$query}");
            $a = explode('<suggestion data="', $doc);
            foreach ($a as $value)
                $sugg[] = mb_strstr($value, '"/>', true, self::enc);
            $sugg = array_slice($sugg, 1);
        }
        return $sugg;
    }

    public function getSuggestionView($suggestion, $textColor)
    {
        return "<text color=\"$textColor\">$suggestion</text>";
    }

    public function getSearchText($suggestion)
    {
        return $suggestion;
    }

    public function getActionParameters($suggestion)
    {
        return null;
    }

    public function isSearchBySuggestionOnly($suggestion)
    {
        return false;
    }
}

?>