#!/bin/sh

log_path=$FS_PREFIX/tmp/run/widget_ext_weather.log
openLog() {
  path="$1"
  [ -f $path ] && size=`stat -t $path | awk '{print $2}'` || size=0
  [ "$size" -gt 20000 ] && mv $path $path.old
}
openLog $log_path
exec >>$log_path 2>&1

ilang=$(grep 'interface_language =' $FS_PREFIX/config/settings.properties | tail -n1 | sed 's/.* = //')
[ "$ilang" = "russian" ] && export LANG="ru_RU.UTF-8"

BASEDIR=$(dirname "$(dirname "$(readlink -f "$0")")"); STORE_IFS=$IFS; IFS='/' path_array=($BASEDIR); IFS=$STORE_IFS; n=${#path_array[@]}
PLUGIN_NAME="${path_array[$n-1]}"
if [ -d /persistfs/plugins_data/$PLUGIN_NAME ]; then              
    DATA_DIR="/persistfs/plugins_data/$PLUGIN_NAME"
elif [ -d $FS_PREFIX/flashdata/plugins_data/$PLUGIN_NAME ]; then            
    DATA_DIR="$FS_PREFIX/flashdata/plugins_data/$PLUGIN_NAME"
else                          
    DATA_DIR=
fi

CURL=""
source $FS_PREFIX/tmp/run/versions.txt
if [ $platform_kind == android ]; then
CURL="$FS_PREFIX/firmware/bin/curl"
elif (echo $platform_kind | grep -E -q "87.."); then
CURL="$BASEDIR/bin/curl.87xx"
elif (echo $platform_kind | grep -E -q "864."); then
CURL="$BASEDIR/bin/curl.864x"
elif (echo $platform_kind | grep -E -q "867."); then
CURL="$BASEDIR/bin/curl.867x"
elif (echo $platform_kind | grep -E -q "865."); then
CURL="$BASEDIR/bin/curl.865x"
fi

cityId=""
addInfoType="city"
if [ -f $DATA_DIR/settings.properties ]; then
    exec <"$DATA_DIR/settings.properties"
    while true; do
        read key op value
        [ "$key" = "" ] && break
        [ "$key" = "gismeteo_cityId" ] && cityId="$value"
        [ "$key" = "addInfoType" ] && addInfoType="$value"
    done
fi
if [ "$cityId" = "0" ]; then
    cityId=""
fi
if [ -f /etc/TZ ]; then
    TZ=$(cat /etc/TZ); export TZ; date +"%d.%m.%Y %T"
else
    date +"%d.%m.%Y %T"
fi
if [ "$cityId" = "" ]; then
    echo "City ID is missing!"
    exit
fi
lang=""
case "$ilang" in
    "russian") lang="ru" ;;
    "ukrainian") lang="ua" ;;
    "german") lang="de" ;;
    *) lang="en" ;;
esac
url="https://services.gismeteo.ru/inform-service/inf_chrome/forecast/?city="$cityId"&lang="$lang
echo "CityId: "$cityId", Lang: "$lang
echo "URL: $url"

tmp="$FS_PREFIX/tmp/weather_tmp.txt"
d_cond=""
d_temp=""
d_city=""

if $CURL -s  --location -k $url -o $tmp; then
    d_city=`cat $tmp | grep '<weather><location ' | sed 's/^.*<weather><location[^<>]* name="\([^"]*\)".*$/\1/'`
    d_temp=`cat $tmp | grep '<fact ' | sed 's/^.*<fact [^>]*>[^<]*<values[^<>]* t="\([^"]*\)".*$/\1/'`
    d_cond=`cat $tmp | grep '<fact ' | sed 's/^.*<fact [^>]*>[^<]*<values[^<>]* icon="\([^"]*\)".*$/\1/'`
    echo "XML loaded: city="$d_city"; temp="$d_temp"; cond="$d_cond
fi
rm -f "$tmp"
if [ "$d_cond" = "" -o "$d_temp" = "" -o "$d_city" = "" ]; then
    echo "Failed to retrieve weather info"
    exit
fi

get_weather_type() {
    if [[ $1 == *st* ]]; then
        echo "thunderstorm"
    elif [[ $1 == *s3* ]]; then
        echo "heavy_snow"
    elif [[ $1 == *s* ]]; then
        echo "snow"
    elif [[ $1 == *r3* ]]; then
        echo "heavy_rain"
    elif [[ $1 == *r* ]]; then
        echo "rain"
    elif [[ $1 == *c3* ]]; then
        echo "heavy_clouds"
    elif [[ $1 == *c2* ]]; then
        echo "clouds"
    elif [[ $1 == *c1* ]]; then
        if [[ $1 == *n* ]]; then
            echo "night_clear_clouds"
        else
            echo "clear_clouds"
        fi
    elif [[ $1 == *c* ]]; then
        echo "heavy_clouds"
    elif [[ $1 == *d* ]]; then
        echo "clear"
    elif [[ $1 == *n* ]]; then
        echo "night_clear"
    else
        echo "unknown"
    fi
}

res_type=$(get_weather_type "$d_cond")
temp_sign=$(echo $d_temp | cut -c -1)
temp_value="0"
if [ "$temp_sign" = "-" ]; then
    temp_sign="-"
    temp_value=$(echo $d_temp | cut -c 2-)
else
    temp_sign="+"
    temp_value=$d_temp
fi
res_temp=$temp_sign$temp_value"C"
###########################################################################
WEATHER_FILE="$FS_PREFIX/tmp/weather.txt"

if [ "$addInfoType" = "weekDay" ]; then
  inf=$(date +"%a")
  [ "$lang" = "ru" -o "$lang" = "ua" ] && \
    inf=$(echo "$inf" | sed "s/Mon/Понедельник/g; s/Tue/Вторник/g; s/Wed/Среда/g; s/Thu/Четверг/g; s/Fri/Пятница/g; s/Sat/Суббота/g; s/Sun/Воскресенье/g")
else
  d_city=$(echo "$d_city" | cut -d',' -f 1)
  lenght=${#d_city}
  if [ "$lenght" -lt 17 ]; then
    let "ext_lenght=17-$lenght"
    A=$(printf "%.${ext_lenght}d" 0 | sed "s/0/  /g")
    inf=$d_city$A
  else
    inf=${d_city:0:17}
  fi
fi

echo "$res_temp $res_type $inf" >"$WEATHER_FILE.tmp"

mv -f "$WEATHER_FILE.tmp" "$WEATHER_FILE"

cat "$WEATHER_FILE"
