#!/bin/sh

log_path=$FS_PREFIX/tmp/run/widget_ext_weather.log
openLog() {
  path="$1"
  [ -f $path ] && size=`stat -t $path | awk '{print $2}'` || size=0
  [ "$size" -gt 20000 ] && mv $path $path.old
}
openLog $log_path
exec >>$log_path 2>&1

BASEDIR=$(dirname "$(dirname "$(readlink -f "$0")")"); STORE_IFS=$IFS; IFS='/' path_array=($BASEDIR); IFS=$STORE_IFS; n=${#path_array[@]}
PLUGIN_NAME="${path_array[$n-1]}"
if [ -d /persistfs/plugins_data/$PLUGIN_NAME ]; then              
    DATA_DIR="/persistfs/plugins_data/$PLUGIN_NAME"
elif [ -d $FS_PREFIX/flashdata/plugins_data/$PLUGIN_NAME ]; then            
    DATA_DIR="$FS_PREFIX/flashdata/plugins_data/$PLUGIN_NAME"
else                          
    DATA_DIR=
fi

cityId=""
addInfoType="city"
if [ -f $DATA_DIR/settings.properties ]; then
    exec <"$DATA_DIR/settings.properties"
    while true; do
        read key op value
        [ "$key" = "" ] && break
        [ "$key" = "rp5_cityId" ] && cityId="$value"
        [ "$key" = "addInfoType" ] && addInfoType="$value"
    done
fi
if [ "$cityId" = "0" ]; then
    cityId=""
fi
if [ -f /etc/TZ ]; then
    TZ=`cat /etc/TZ`; export TZ; date +"%d.%m.%Y %T"
else
    date +"%d.%m.%Y %T"
fi
if [ "$cityId" = "" ]; then
    echo "City ID is missing!"
    exit
fi
language=""
if [ -f $FS_PREFIX/config/settings.properties ]; then
    exec <"$FS_PREFIX/config/settings.properties"
    while true; do
        read key op value
        [ "$key" = "" ] && break
        [ "$key" = "interface_language" ] && language="$value"
    done
fi
lang=""
case "$language" in
    "russian") lang="ru" ;;
    "ukrainian") lang="ua" ;;
    "german") lang="de" ;;
    *) lang="en" ;;
esac
url="http://rp5.ru/flash.php?id="$cityId"&lang="$lang
echo "CityId: "$cityId", Lang: "$lang
echo "URL: $url"
tmp="$FS_PREFIX/tmp/weather_tmp.txt"
d_cond=""
d_temp=""
d_city=""
if wget -O "$tmp" "$url"; then
    startsWith=`cat $tmp | cut -c -2`
    if [ "$startsWith" = "p=" ]; then
        d_city=`cat $tmp | cut -f1 -d"&" | cut -f2 -d"="`
        d_temp=`cat $tmp | cut -f3 -d"&" | cut -f2 -d"="`
        temp_len=`expr length $d_temp`
        temp_end=$(($temp_len-3))
        d_temp=`echo $d_temp | cut -c 1-$temp_end`
        d_cond=`cat $tmp | cut -f7 -d"&" | cut -f2 -d"="`
        d_cond2=`cat $tmp | cut -f8 -d"&" | cut -f2 -d"="`
        echo "XML loaded: city="$d_city"; temp="$d_temp"; cond="$d_cond"; cond2="$d_cond2
    fi
fi
rm -f "$tmp"
if [ "$d_cond" = "" -o "$d_temp" = "" -o "$d_city" = "" ]; then
    echo "Failed to retrieve weather info"
    exit
fi

get_weather_type() {
    if [ "$2" = "0" ]; then
        condNr=`echo $1 | cut -c 3-`
        case $condNr in
            0) echo "clear" ;;
            1|2|3|4) echo "clear_clouds" ;;
            5|6|7) echo "clouds" ;;
            *) echo "unknown" ;;
        esac
    else
        condNr2=`echo $2 | cut -c 2-2`
        case $condNr2 in
            1) echo "rain" ;;
            2|3) echo "snow" ;;
            *) echo "unknown" ;;
        esac
    fi
}

res_type=`get_weather_type "$d_cond" "$d_cond2"`
temp_sign=`echo $d_temp | cut -c -1`
temp_value="0"
if [ "$temp_sign" = "+" ]; then
    temp_sign="+"
    temp_value=`echo $d_temp | cut -c 2-`
else
    temp_sign="-"
    temp_value=`echo $d_temp | cut -c 2-`
fi
res_temp=$temp_sign$temp_value"C"

###########################################################################
WEATHER_FILE="$FS_PREFIX/tmp/weather.txt"

if [ "$addInfoType" = "weekDay" ]; then
  inf=$(date +"%a")
  [ "$lang" = "ru" -o "$lang" = "ua" ] && \
    inf=$(echo "$inf" | sed "s/Mon/Понедельник/g; s/Tue/Вторник/g; s/Wed/Среда/g; s/Thu/Четверг/g; s/Fri/Пятница/g; s/Sat/Суббота/g; s/Sun/Воскресенье/g")
else
  d_city=$(echo "$d_city" | cut -d',' -f 1)
  lenght=${#d_city}
  if [ "$lenght" -lt 17 ]; then
    let "ext_lenght=17-$lenght"
    A=$(printf "%.${ext_lenght}d" 0 | sed "s/0/  /g")
    inf=$d_city$A
  else
    inf=${d_city:0:17}
  fi
fi

echo "$res_temp $res_type $inf" >"$WEATHER_FILE.tmp"

mv -f "$WEATHER_FILE.tmp" "$WEATHER_FILE"

cat "$WEATHER_FILE"
