<?php


class HD
{
    public static function is_map($a)
    {
        return is_array($a) &&
            array_diff_key($a, array_keys(array_keys($a)));
    }

    

    public static function has_attribute($obj, $n)
    {
        $arr = (array) $obj;
        return isset($arr[$n]);
    }
    

    public static function get_map_element($map, $key)
    {
        return isset($map[$key]) ? $map[$key] : null;
    }

    

    public static function starts_with($str, $pattern)
    {
        return strpos($str, $pattern) === 0;
    }

    

    public static function format_timestamp($ts, $fmt = null)
    {
        // NOTE: for some reason, explicit timezone is required for PHP
        // on Dune (no builtin timezone info?).

        if (is_null($fmt))
            $fmt = 'Y:m:d H:i:s';

        $dt = new DateTime('@' . $ts);
        return $dt->format($fmt);
    }

    

    public static function format_duration($msecs)
    {
        $n = intval($msecs);

        if (strlen($msecs) <= 0 || $n <= 0)
            return "--:--";

        $n = $n / 1000;
        $hours = $n / 3600;
        $remainder = $n % 3600;
        $minutes = $remainder / 60;
        $seconds = $remainder % 60;

        if (intval($hours) > 0)
        {
            return sprintf("%d:%02d:%02d", $hours, $minutes, $seconds);
        }
        else
        {
            return sprintf("%02d:%02d", $minutes, $seconds);
        }
    }

    

    public static function encode_user_data($a, $b = null)
    {
        $media_url = null;
        $user_data = null;

        if (is_array($a) && is_null($b))
        {
            $media_url = '';
            $user_data = $a;
        }
        else
        {
            $media_url = $a;
            $user_data = $b;
        }

        if (!is_null($user_data))
            $media_url .= '||' . json_encode($user_data);

        return $media_url;
    }

    

    public static function decode_user_data($media_url_str, &$media_url, &$user_data)
    {
        $idx = strpos($media_url_str, '||');

        if ($idx === false)
        {
            $media_url = $media_url_str;
            $user_data = null;
            return;
        }

        $media_url = substr($media_url_str, 0, $idx);
        $user_data = json_decode(substr($media_url_str, $idx + 2));
    }

    

    public static function create_regular_folder_range($items,
        $from_ndx = 0, $total = -1, $more_items_available = false)
    {
        if ($total === -1)
            $total = $from_ndx + count($items);

        if ($from_ndx >= $total)
        {
            $from_ndx = $total;
            $items = array();
        }
        else if ($from_ndx + count($items) > $total)
        {
            array_splice($items, $total - $from_ndx);
        }

        return array
        (
            PluginRegularFolderRange::total => intval($total),
            PluginRegularFolderRange::more_items_available => $more_items_available,
            PluginRegularFolderRange::from_ndx => intval($from_ndx),
            PluginRegularFolderRange::count => count($items),
            PluginRegularFolderRange::items => $items
        );
    }

    

    public static function http_get_document($url, $opts = null)
    {
        $ch = curl_init();
        
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 	0);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 	0);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT,    11);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION,    1);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER,    true);
        curl_setopt($ch, CURLOPT_TIMEOUT,           10);
        curl_setopt($ch, CURLOPT_USERAGENT,         "Mozilla/5.0 (Windows NT 10.0; WOW64; rv:53.0) Gecko/20100101 Firefox/53.0");
        curl_setopt($ch, CURLOPT_ENCODING,          1);
        curl_setopt($ch, CURLOPT_URL,               $url);
        
//         curl_setopt($ch, CURLOPT_CONNECTTIMEOUT,    20);
//         curl_setopt($ch, CURLOPT_RETURNTRANSFER,    true);
//         curl_setopt($ch, CURLOPT_TIMEOUT,           20);
//         curl_setopt($ch, CURLOPT_USERAGENT,         'DuneHD/1.0');
//         curl_setopt($ch, CURLOPT_URL,               $url);

        if (isset($opts))
        {
            foreach ($opts as $k => $v)
                curl_setopt($ch, $k, $v);
        }

        hd_print("HTTP fetching '$url'...");

        $content = curl_exec($ch);
        $http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);

        if($content === false)
        {
            $err_msg = "HTTP error: $http_code (" . curl_error($ch) . ')';
            hd_print($err_msg);
            throw new Exception($err_msg);
        }

        if ($http_code != 200)
        {
            $err_msg = "HTTP request failed ($http_code)";
            hd_print($err_msg);
            throw new Exception($err_msg);
        }

        hd_print("HTTP OK ($http_code)");

        curl_close($ch);

        return $content;
    }

    

    public static function http_post_document($url, $post_data)
    {
        return self::http_get_document($url,
            array
            (
                CURLOPT_POST => true,
                CURLOPT_POSTFIELDS => $post_data
            ));
    }

    

    public static function parse_xml_document($doc)
    {
        $xml = simplexml_load_string($doc);

        if ($xml === false)
        {
            hd_print("Error: can not parse XML document.");
            hd_print("XML-text: $doc.");
            throw new Exception('Illegal XML document');
        }

        return $xml;
    }

    

    public static function make_json_rpc_request($op_name, $params)
    {
        static $request_id = 0;

        $request = array
        (
            'jsonrpc' => '2.0',
            'id' => ++$request_id,
            'method' => $op_name,
            'params' => $params
        );

        return $request;
    }
    
    public static function get_ip_address()
    {
        static $ip_address = null;
        
        if (is_null($ip_address))
        {
            //hd_print(__METHOD__);
            $withV6 = true;
            preg_match_all('/inet'.($withV6 ? '6?' : '').' addr: ?([^ ]+)/', `ifconfig`, $ips);
            //hd_print(print_r($ips[1], true));
            $ip_address = array_shift($ips[1]);
        }
        
        return $ip_address;
    }

    // TODO: localization
    private static $MONTHS = array(
        'January',
        'February',
        'March',
        'April',
        'May',
        'June',
        'July',
        'August',
        'September',
        'October',
        'November',
        'December',
    );

    public static function format_date_time_date($tm)
    {
        $lt = localtime($tm);
        $mon = self::$MONTHS[$lt[4]];
        return sprintf("%02d %s %04d", $lt[3], $mon, $lt[5] + 1900);
    }

    public static function format_date_time_time($tm, $with_sec = false)
    {
        $format = '%H:%M';
        if ($with_sec)
            $format .= ':%S';
        return strftime($format, $tm);
    }

    public static function print_backtrace()
    {
        hd_print('Back trace:');
        foreach (debug_backtrace() as $f)
        {
            hd_print(
                '  - ' . $f['function'] . 
                ' at ' . $f['file'] . ':' . $f['line']);
        }
    }
    
    public static function get_data_path($reset = null)
    {
        static $link = null;
        if ($reset == true)
            $link = null;
            if (is_null($link)) {
                $link = DuneSystem::$properties['data_dir_path'];
                if (file_exists($link . '/data_dir_path'))
                    $link = smbtree::get_folder_info('data_dir_path');
            }
            return $link;
    }
    
    public static function get_items($path, $macAdr = null)
    {
        $items = array();
        if ($macAdr == true)
            $path = $path . self::get_mac_addr(1);
        if ($path == 'data_dir_path')
            $link = DuneSystem::$properties['data_dir_path'] . '/' . $path;
        else
            $link = self::get_data_path() . '/' . $path;
        if (file_exists($link))
            $items = unserialize(file_get_contents($link));
        return $items;
    }

    public static function save_items($path, $items, $macAdr = null)
    {
        if ($macAdr == true)
            $path = $path . self::get_mac_addr(1);
        if ($path == 'data_dir_path')
            $link = DuneSystem::$properties['data_dir_path'] . '/' . $path;
        else
            $link = self::get_data_path() . '/' . $path;
        file_put_contents($link, serialize($items));
    }

    public static function get_mac_addr($arg = null)
    {
        static $mac_addr = null;
        if (is_null($mac_addr)) {
            $mac_addr = shell_exec('ifconfig  eth0 | head -1 | sed "s/^.*HWaddr //"');
            $mac_addr = trim($mac_addr);
        }
        if ($arg == true)
            $mac_addr = str_replace(":", "", $mac_addr);
        return $mac_addr;
    }

    public static function get_item($path, $macAdr = null)
    {
        $item = '';
        if ($macAdr == true)
            $path = $path . self::get_mac_addr(1);
        $link = self::get_data_path() . '/' . $path;
        if (file_exists($link))
            $item = file_get_contents($link);
        return $item;
    }
    public static function str_remove_tag($str)
    {
        if (preg_match("|(.*?)<font color='green'>Отзывы|ms", $str, $matches))
            $str = $matches[1];

        $search = array(
            '@<script[^>]*?>.*?</script>@si', // Strip out javascript
            '@<[\/\!]*?[^<>]*?>@si', // Strip out HTML tags
            '@<style[^>]*?>.*?</style>@siU', // Strip style tags properly
            '|.*{.*}|'
        );
        $str = preg_replace($search, '', $str);
        $str = strip_tags($str);
        $str = str_replace("●", "*", $str);
        $str = str_replace("&nbsp;", " ", $str);
        $str = str_replace("&mdash;", "", $str);
        $str = str_replace(array(
            "&hellip;",
            '&thinsp;'
        ), "", $str);
        $str = str_replace("&#8211;", " - ", $str);
        $str = str_replace("&ndash;", " - ", $str);
        $str = str_replace("&oacute;", "'", $str);
        $str = str_replace(array(
            "&laquo;",
            "&raquo;"
        ), "'", $str);
        $str = preg_replace("|&\S+?;|", "", $str);
        $str = html_entity_decode($str);
        $str = str_replace(array(
            '"',
            '«',
            '»'
        ), "'", $str);
        $str = preg_replace('/\s{2,}/', ' ', $str);
        $str = trim($str);
        return $str;
    }
    
    public static function get_STB_locale(){
        $propertiesFile = realpath("/config/settings.properties");
        if ($propertiesFile) {
            $handle = fopen($propertiesFile, "r");
            if ($handle) {
                while (($buffer = fgets($handle)) !== false) {
                    $pos = strpos($buffer, "interface_language = "); //robust but fast comparison
                    if ($pos !== false) {
                        $result = trim(substr($buffer, $pos + strlen("interface_language = ")));
                        fclose($handle);
                        return $result;
                    }
                }
                if (!feof($handle))
                    hd_print("Get current player locale failed.");
                    fclose($handle);
            }
        }
        hd_print("interface_language setting not found. Default STB locale = english");
        return "english";
    }
    
}


?>
