﻿<?php
require_once 'lib/screen.php';
require_once 'lib/user_input_handler.php';
require_once 'view_utils.php';

class WidgetExtPluginScreen implements Screen, UserInputHandler {
	
	const ID = 'plugins_screen';
    const INSTALLED_PLUGINS_FILE = '/tmp/run/installed_plugins.xml';
	
	private $settings;
	
	public function __construct(Settings $settings) {
		$this->settings = $settings;
        UserInputHandlerRegistry::get_instance()->register_handler($this);
	}
	
	public function get_id() {
		return self::ID;
	}

	public function get_handler_id() {
		return 'controls_'.$this->get_id();
	}
	
	public static function get_media_url_str() {
		return MediaURL::encode(array('screen_id' => self::ID));
	}
	
	public function get_folder_view(MediaURL $media_url, &$plugin_cookies) {
		$initial_range = $this->get_plugins_items($plugin_cookies);
		$actions = $this->get_plugins_action_map();
		$view = ViewUtils::createRegularFolderView_List($initial_range, $actions);
		return $view;
	}
    
    private function get_plugins_items($plugin_cookies) {
    	$items = array();
    	$allPlugins = $this->getPluginList();
    	$ignoredPlugins = $this->getIgnoredPlugins();
    	foreach ($ignoredPlugins as $item) {
    		if ($item !== "") {
	    		array_push($items, ViewUtils::createRegularFolderItem_List(
	    			HD::encode_user_data(array('plugin' => urlencode($item), 'state' => 'ignored')),
	    			"["._("ignored")."] ".$item
	    		));
    		}
    	}
    	foreach ($allPlugins as $item) {
    		if ($item !== "" && !in_array($item, $ignoredPlugins)) {
	    		array_push($items, ViewUtils::createRegularFolderItem_List(
	    			HD::encode_user_data(array('plugin' => urlencode($item), 'state' => '')),
	    			$item
	    		));
    		}
    	}
    	return ViewUtils::createRegularFolderItems($items);
    }
    
    public function get_plugins_action_map() {
    	$ignore_unignore_plugin_action = ViewUtils::createAction('ignore_unignore_plugin',
    			$this->get_handler_id(), _("Ignore/Unignore"));
    	return array (
        	GUI_EVENT_KEY_D_BLUE => $ignore_unignore_plugin_action,
            GUI_EVENT_KEY_ENTER => $ignore_unignore_plugin_action,
        );
    }
    
    public function handle_user_input(&$user_input, &$plugin_cookies) {
    	$this->settings->init();
    	$control_id = $user_input->control_id;
    	switch ($control_id) {
    	case 'ignore_unignore_plugin':
        	if (!isset($user_input->selected_media_url)) return null;
        	HD::decode_user_data($user_input->selected_media_url, $media_str, $user_data);
        	$plugin = urldecode($user_data->plugin);
        	$state = urldecode($user_data->state);
        	$ignoredPlugins = $this->getIgnoredPlugins();
        	if ($state == 'ignored') {
				$ignoredPlugins = $this->removeIgnoredPlugin($plugin);
			} else {
				$ignoredPlugins = $this->addIgnoredPlugin($plugin);
			}
        	return ViewUtils::update_regular_folder(
        			$this->get_plugins_items($plugin_cookies),
        			true
        	);
    	}
    }
	
    private function getPluginList() {
    	$plugins = array();
    	$doc = file_get_contents(self::INSTALLED_PLUGINS_FILE);
    	if ($doc !== false) {
    		$xml = simplexml_load_string($doc);
	    	if ($xml !== false) {
	    		foreach ($xml->children() as $plugin) {
	    			$pluginName = strval($plugin->name);
	    			$plugins[] = $pluginName;
	    		}
	    	} else {
	    		hd_print("Cannot parse installed-plugins file.");
	    	}
    	} else {
    		hd_print("Installed plugins file not exist.");
    	}
    	natcasesort($plugins);
    	return $plugins;
    }
	
    private function getIgnoredPlugins() {
    	$ignoredPlugins = $this->settings->getIgnoredPlugins();
    	if ($ignoredPlugins) {
    		return explode(",", $ignoredPlugins);
    	}
    	return array();
    }
	
    private function saveIgnoredPlugins($ignoredPlugins) {
    	$data = "";
    	if ($ignoredPlugins) {
    		$data = implode(",", $ignoredPlugins);
    	}
    	$this->settings->setIgnoredPlugins($data);
    }
	
    private function removeIgnoredPlugin($plugin) {
    	$removed = false;
    	$newIgnoredPlugins = array();
    	$ignoredPlugins = $this->getIgnoredPlugins();
    	if ($ignoredPlugins) {
    		foreach ($ignoredPlugins as $ignoredPlugin) {
    			if ($ignoredPlugin != $plugin) {
    				$newIgnoredPlugins[] = $ignoredPlugin;
    			} else {
    				$removed = true;
    			}
    		}
    	}
    	if ($removed) {
    		$this->saveIgnoredPlugins($newIgnoredPlugins);
    	}
    }
	
    private function addIgnoredPlugin($plugin) {
    	$ignoredPlugins = $this->getIgnoredPlugins();
    	if ($ignoredPlugins) {
    		foreach ($ignoredPlugins as $ignoredPlugin) {
    			if ($ignoredPlugin == $plugin) {
    				return;
    			}
    		}
    	}
    	$ignoredPlugins[] = $plugin;
    	$this->saveIgnoredPlugins($ignoredPlugins);
    }
}
?>