﻿<?php
require_once 'lib/abstract_controls_screen.php';
require_once 'adv_keyboards/adv_keyboard.php';
require_once 'adv_keyboards/suggestions_gismeteo.php';

class WidgetExtSetupScreen extends AbstractControlsScreen {
	
	const ID = 'setup_screen';
	
	private $seq = null;
	private $settings;
	
	public function __construct(Settings $settings) {
		parent::__construct(self::ID);
		$this->settings = $settings;
	}
	
	public static function get_media_url_str() {
		return MediaURL::encode(array('screen_id' => self::ID));
	}
	
	public function get_control_defs(MediaURL $media_url, &$plugin_cookies) {
		return $this->createControlDefs($plugin_cookies);
	}
	
	private function createControlDefs(&$plugin_cookies) {
		$this->settings->init();
		$defs = array();
		$oldFixWidgetInstalled = $this->isOldFixWidgetInstalled();
		if ($oldFixWidgetInstalled) {
			ControlFactory::add_smart_label($defs, _("WARNING").":",
					_c(4, "The rests of old fix_widget found!!!"));
			$this->add_button($defs, 'old_fix_cleanup', "",
					_("Clean-up old fix_widget"), -1);
		} else {
			$ops = array();
			$ops["no"] = _("Disable Weather Fix");
			$ops["openweathermap"] = _("OpenWeatherMap.org");
			$ops["yandex"] = _("Yandex.ru");
			$ops["rp5"] = _("rp5.ru");
			$ops["gismeteo"] = _("Gismeteo");
			//$ops["test"] = _("TEST");
			$this->add_combobox($defs, 'fix_enabled', _("Weather service"),
					$this->settings->getFixEnabled(), $ops, -1, false, true);
			if ($this->settings->getFixEnabled() != 'no') {
				$ops = array();
                if (is_file("/config/weather_ext_debug"))
                    $ops[1] = _("1 min");
				$ops[15] = _("15 min");
				$ops[30] = _("30 min");
				$ops[60] = _("1 hour");
				$ops[120] = _("2 hours");
				$ops[180] = _("3 hours");
				$ops[360] = _("6 hours");
				$this->add_combobox($defs, 'weatherUpdateInterval', _("Update interval"),
						$this->settings->getWeatherUpdateInterval(), $ops, -1, false, true);
				$canUpdate = false;
				if ($this->settings->getFixEnabled() == 'openweathermap') {
					$apiKey = $this->settings->getApiKey();
					$this->add_text_field($defs, 'apiKey', _("API key"),
							$apiKey, false, false, false, false, -1, false, true);
					if ($apiKey) {
						$canUpdate = true;
					} else {
						$this->add_button($defs, 'key_from_hdd', "",
								_("Load apikey.txt from HDD"), -1);
					}
				} else if ($this->settings->getFixEnabled() == 'yandex') {
					$yandexCityId = $this->settings->getYandexCityId();
					if ($yandexCityId == 0) {
						$yandexCityId = "";
					}
					$this->add_text_field($defs, 'yandex_cityId', _("City GEOID"),
							$yandexCityId, true, false, false, false, -1, false, true);
					$canUpdate = true;
				} else if ($this->settings->getFixEnabled() == 'rp5') {
					$rp5CityId = $this->settings->getRp5CityId();
					if ($rp5CityId == 0) {
						$rp5CityId = "";
					}
					$this->add_text_field($defs, 'rp5_cityId', _("City ID"),
							$rp5CityId, true, false, false, false, -1, false, true);
					$canUpdate = true;
				} else if ($this->settings->getFixEnabled() == 'gismeteo') {
				    $gismeteoCityName = $this->settings->getGismeteoCityName(self::getGuiLang());
				    $btnTitle = $gismeteoCityName ? $gismeteoCityName : _("Select...");
					$this->add_button($defs, 'search_gismeteo_city', _("City"), $btnTitle, -1);
					$canUpdate = true;
				}
				if ($canUpdate) {
					$this->add_button($defs, 'update_weather', "",
							_("Update weather now"), -1);
				}
			}
		}
		$this->add_vgap($defs, 20);
		$yes_no_ops = array();
		$yes_no_ops['yes'] = _('Yes');
		$yes_no_ops['no'] = _('No');
		$this->add_combobox($defs, 'showMemInfo', _("Show memory info"),
				$this->settings->getShowMemInfo(), $yes_no_ops, -1, false, true);
		$ops = array();
		$ops[0] = _("Don't clean-up memory");
		for ($i = 1; $i<=20; $i++) {
			$ops[$i] = $i."%";
		}
		$this->add_combobox($defs, 'cleanMemoryThreshold', _("Memory threshold"),
				$this->settings->getCleanMemoryThreshold(), $ops, -1, false, true);
		$ignoredPlugins = $this->settings->getIgnoredPlugins();
		$ignoredPluginsCount = 0;
		if ($ignoredPlugins) {
			$pluginsArray = explode(",", $ignoredPlugins);
			$ignoredPluginsCount = count($pluginsArray);
		}
		$this->add_button($defs, 'setup_ignored_plugins',
				_("Ignored plug-ins").": ".$ignoredPluginsCount, _("Select..."), -1);
		$this->add_button($defs, 'memory_cleanup', "", _("Clean-up memory now"), -1);

		$this->add_vgap($defs, 20);

        $ops = array('city' => _('No'), 'weekDay' => _('Yes'));
        $this->add_combobox($defs, 'addInfoType', _("Show day of the week"),
                $this->settings->getAddInfoType(), $ops, -1, false, true);

		$this->add_button($defs, 'showLog', "", _("Log of last actions"), -1);
		return $defs;
	}
	
	private function createLogDefs(&$plugin_cookies, $isMemory) {
		$defs = array();
		$st = "";
		if ($isMemory) {
			$this->add_close_dialog_and_apply_button($defs, 'showLog', "<< "._("Weather"), -1);
			if (!$this->isMeminfoCronRunning()) {
				$st = "not ";
			}
		} else {
			$this->add_close_dialog_and_apply_button($defs, 'showLog2',  _("Memory")." >>", -1);
			if (!$this->isWeatherCronRunning()) {
				$st = "not ";
			}
		}
		$this->add_label($defs, "", "Status: ".($isMemory ? "Memory" : "Weather")." cron is ".$st."running");
		$filePath = '/tmp/run/widget_ext_'.($isMemory ? 'memory' : 'weather').'.log';
		if (file_exists($filePath)) {
		    $texts = file($filePath);
    		$texts = array_values($texts);
    		foreach($texts as $text) {
    			$this->add_label($defs, "", trim($text));
    		}
		}
		$this->add_close_dialog_button($defs, _("Close"), 150);
		return $defs;
	}
	
	public function handle_user_input(&$user_input, &$plugin_cookies) {
		$this->settings->init();
		$control_id = $user_input->control_id;
		if ($control_id != 'old_fix_cleanup'
				&& $control_id != 'memory_cleanup'
				&& $control_id != 'setup_ignored_plugins'
				&& $control_id != 'update_weather'
				&& $control_id != 'search_gismeteo_city'
				&& $control_id != 'key_from_hdd'
				&& $control_id != 'showLog'
				&& $control_id != 'showLog2') {
			$value = $user_input->$control_id;
		}
		switch ($control_id) {
			case 'old_fix_cleanup':
				$this->cleanUpOldFix();
				break;
			case 'memory_cleanup':
				$this->cleanUpMemory();
				break;
			case 'setup_ignored_plugins':
				return ActionFactory::open_folder("plugins_screen", _("Ignored plug-ins"));
			case 'update_weather':
				$this->updateWeather();
				break;
			case 'key_from_hdd':
				$this->loadApiKeyFromHDD();
				break;
			case 'showLog':
				$defs = $this->createLogDefs($plugin_cookies, false);
				return ActionFactory::show_dialog(_("Log of last actions"), $defs, true, 1200);
			case 'showLog2':
				$defs = $this->createLogDefs($plugin_cookies, true);
				return ActionFactory::show_dialog(_("Log of last actions"), $defs, true, 1200);
			case 'fix_enabled':
				$oldValue = $this->settings->getFixEnabled();
				$this->settings->setFixEnabled($value);
				if ($oldValue != $value) {
					$this->onFixEnabledChange($oldValue, $value);
				}
				break;
			case 'weatherUpdateInterval':
				$oldValue = $this->settings->getWeatherUpdateInterval();
				$this->settings->setWeatherUpdateInterval($value);
				if ($oldValue != $value) {
					$this->onWeatherUpdateInterval($oldValue, $value);
				}
				break;
			case 'addInfoType':
				$oldValue = $this->settings->getAddInfoType();
				$this->settings->setAddInfoType($value);
				if ($oldValue != $value)
                {
                    $this->updateWeather();
                    sleep(1);
                }
				break;
			case 'apiKey':
				$oldValue = $this->settings->getApiKey();
				$this->settings->setApiKey($value);
				if ($oldValue != $value) {
					$this->onApiKeyChange($oldValue, $value);
				}
				break;
			case 'yandex_cityId':
				$oldValue = $this->settings->getYandexCityId();
				$this->settings->setYandexCityId($value);
				if ($oldValue != $value) {
					$this->onYandexCityIdChange($oldValue, $value);
				}
				break;
			case 'rp5_cityId':
				$oldValue = $this->settings->getRp5CityId();
				$this->settings->setRp5CityId($value);
				if ($oldValue != $value) {
					$this->onRp5CityIdChange($oldValue, $value);
				}
				break;
			case 'gismeteo_cityId':
				$oldValue = $this->settings->getGismeteoCityId();
				$this->settings->setGismeteoCityId($value);
				$this->settings->setGismeteoCityNames($user_input->gismeteo_cityNames);
				if ($oldValue != $value) {
					$this->onGismeteoCityIdChange($oldValue, $value);
				}
				break;
			case 'search_gismeteo_city':
			    return $this->searchGismeteoCity($user_input, $plugin_cookies);
			case 'showMemInfo':
				$oldValue = $this->settings->getShowMemInfo();
				$this->settings->setShowMemInfo($value);
				if ($oldValue != $value) {
					$this->onShowMemInfoChange($oldValue, $value);
				}
				break;
			case 'cleanMemoryThreshold':
				$value = intval($value);
				$oldValue = $this->settings->getCleanMemoryThreshold();
				$this->settings->setCleanMemoryThreshold($value);
				if ($oldValue != $value) {
					$this->onCleanMemoryThreshold($oldValue, $value);
				}
				break;
		}
		return ActionFactory::reset_controls($this->createControlDefs(
				$plugin_cookies));
	}
	
	private function isOldFixWidgetInstalled() {
		return file_exists("/config/boot/fix_widget.sh");
	}
	
	private function cleanUpOldFix() {
		sh("bin/clean_old_fix.sh");
	}
	
	private function cleanUpMemory() {
		sh("bin/meminfo.sh x");
	}
	
	private function updateWeather() {
        sh("bin/update_weather.sh");
	}
	
	private function loadApiKeyFromHDD() {
		if (file_exists("/D/apikey.txt")) {
			$this->loadApiKey("/D/apikey.txt");
		} else {
			foreach (glob('/tmp/mnt/storage/*') as $file) {
				if (is_dir($file)) {
					echo $file;
					if (file_exists($file."/apikey.txt")) {
						echo "loading API key from ".$file."/apikey.txt";
						$this->loadApiKey($file."/apikey.txt");
						break;
					}
				}
			}
		}
	}
	
	private function loadApiKey($path) {
		$apiKey = file_get_contents($path);
		if (substr($apiKey, 0, 3) == pack("CCC", 0xEF, 0xBB, 0xBF)) {
			$apiKey = substr($apiKey, 3);
		}
		$apiKey = trim($apiKey);
		if ($apiKey) {
			$this->settings->setApiKey($apiKey);
			$this->onApiKeyChange("", $apiKey);
		}
	}
	
	private function onFixEnabledChange($oldValue, $value) {
		if ($value == "no") {
			sh("bin/rmcron_fix.sh");
		} else {
			sh("bin/mkcron_fix.sh");
		}
	}
	
	private function onWeatherUpdateInterval($oldValue, $value) {
		sh("bin/mkcron_fix.sh");
	}
	
	private function onApiKeyChange($oldValue, $value) {
		sh("bin/update_weather.sh");
	}
	
	private function onYandexCityIdChange($oldValue, $value) {
		sh("bin/update_weather.sh");
	}
	
	private function onRp5CityIdChange($oldValue, $value) {
		sh("bin/update_weather.sh");
	}

	private function onGismeteoCityIdChange($oldValue, $value) {
		sh("bin/update_weather.sh");
	}
	
	private function onShowMemInfoChange($oldValue, $value) {
		$updateWeather = false;
		$threshold = $this->settings->getCleanMemoryThreshold();
		if ($threshold <= 0) {
			if ($value == "yes") {
				sh("bin/mkcron_meminfo.sh");
			} else {
				sh("bin/rmcron_meminfo.sh");
				$updateWeather = true;
			}
		} else {
			if ($value == "yes") {
				sh("bin/meminfo.sh");
			} else {
				$updateWeather = true;
			}
		}
		if ($updateWeather) {
			$fixEnabled = $this->settings->getFixEnabled();
			if ($fixEnabled == "no") {
				sh_ext("/firmware/scripts/run_widget.sh");
			} else {
				sh("bin/update_weather.sh");
			}
		}
	}
	
	private function onCleanMemoryThreshold($oldValue, $value) {
		$showMemInfo = $this->settings->getShowMemInfo();
		if ($showMemInfo != "yes") {
			if ($value > 0) {
				sh("bin/mkcron_meminfo.sh");
			} else {
				sh("bin/rmcron_meminfo.sh");
			}
		} else {
			if ($value > 0) {
				sh("bin/meminfo.sh");
			}
		}
	}
	
	private function isWeatherCronRunning() {
	    $result = shell_exec(DuneSystem::$properties['install_dir_path']."/bin/crontask.sh | grep 'update_weather.sh'");
	    hd_print("isWeatherCronRunning: ".$result);
	    // 		$result = system("crontab -u root -l | grep 'update_weather.sh'");
	    if ($result) {
	        return true;
	    } else {
	        return false;
	    }
	}
	
	private function isMeminfoCronRunning() {
	    $result = shell_exec(DuneSystem::$properties['install_dir_path']."/bin/crontask.sh | grep 'meminfo.sh'");
	    hd_print("isMeminfoCronRunning: ".$result);
	    // 		$result = system("crontab -u root -l | grep 'meminfo.sh'");
	    if ($result) {
	        return true;
	    } else {
	        return false;
	    }
	}
	
	private function searchGismeteoCity(&$user_input, &$plugin_cookies)
    {
        $parent_media_url = MediaURL::decode($user_input->parent_media_url);
        $advKeys = new AdvKeyboard($parent_media_url, $plugin_cookies, $this, 'gismeteo_cityId');
        $advKeys->suggestionsProvider = new GismeteoSuggestionsProvider(self::getGuiLang());
        $advKeys->minLengthForSuggestions = 2;
        $advKeys->searchAndSelectMode = true;
        $lang = AdvKeyboard::get_STB_locale();
        if ($lang == 'ukrainian') {
            $advKeys->userKbrds = array(
                0 => 'ukrainian',
                1 => 'english',
                2 => 'russian'
            );
        } elseif ($lang == 'russian') {
            $advKeys->userKbrds = array(
                0 => 'russian',
                1 => 'english',
                2 => 'ukrainian'
            );
        } elseif ($lang == 'german') {
            $advKeys->userKbrds = array(
                0 => 'german',
                1 => 'russian',
                2 => 'ukrainian'
            );
        } else {
            $advKeys->userKbrds = array(
                0 => 'english',
                1 => 'russian',
                2 => 'ukrainian'
            );
        }
        return $advKeys->startup_kbrd();
    }
    
    private static function getGuiLang() {
        $lang = stbLocale();
        if ($lang == "russian") {
            return "ru";
        } elseif ($lang == "ukrainian") {
            return "ua";
        } elseif ($lang == "german") {
            return "de";
        } else {
            return "en";
        }
    }
	
}

function sh($relatviePath) {
	sh_ext(DuneSystem::$properties['install_dir_path']."/".$relatviePath);
}
	
function sh_ext($path) {
	shell_exec($path." > /dev/null &");
}
?>
