<?php
class Settings {

	private $initialized = false;
	
	private $fix_enabled = "no";
	private $apiKey = "";
    private $weatherUpdateInterval = 60;
    private $showMemInfo = "no";
    private $cleanMemoryThreshold = 0;
    private $ignoredPlugins = "";
    private $yandex_cityId = "";
    private $rp5_cityId = "";
    private $gismeteo_cityId = "";
    private $gismeteo_cityNames = "";
    private $addInfoType = 'city';

    public function init() {
    	if (!$this->initialized) {
        	$this->reload();
        	$this->initialized = true;
    	}
    }

    public function reload() {
    	$properties = $this->read();
    	$this->fix_enabled = isset($properties['fix_enabled']) ?
    			$properties['fix_enabled'] : "no";
    	if ($this->fix_enabled == "yes") {
    		$this->fix_enabled = "openweathermap";
    	}
    	$this->apiKey = isset($properties['apiKey']) ?
    			$properties['apiKey'] : "";
    	$this->weatherUpdateInterval = isset($properties['weatherUpdateInterval']) ?
    			intval($properties['weatherUpdateInterval']) : 60;
    	$this->showMemInfo = isset($properties['showMemInfo']) ?
    			$properties['showMemInfo'] : "no";
    	$this->cleanMemoryThreshold = isset($properties['cleanMemoryThreshold']) ?
    			intval($properties['cleanMemoryThreshold']) : 0;
    	$this->ignoredPlugins = isset($properties['ignoredPlugins']) ?
    			$properties['ignoredPlugins'] : "";
    	$this->yandex_cityId = isset($properties['yandex_cityId']) ?
    			intval($properties['yandex_cityId']) : 0;
    	$this->rp5_cityId = isset($properties['rp5_cityId']) ?
    			intval($properties['rp5_cityId']) : 0;
    	$this->gismeteo_cityId = isset($properties['gismeteo_cityId']) ?
    	        intval($properties['gismeteo_cityId']) : 0;
        $this->gismeteo_cityNames = isset($properties['gismeteo_cityNames']) ?
    	        $properties['gismeteo_cityNames'] : "";
    	$this->addInfoType = isset($properties['addInfoType']) ?
            $properties['addInfoType'] : 'city';
    }

    public function save() {
    	$properties = array();
    	$properties['fix_enabled'] = $this->fix_enabled;
    	$properties['apiKey'] = $this->apiKey;
    	$properties['weatherUpdateInterval'] = $this->weatherUpdateInterval;
    	$properties['showMemInfo'] = $this->showMemInfo;
    	$properties['cleanMemoryThreshold'] = $this->cleanMemoryThreshold;
    	$properties['ignoredPlugins'] = $this->ignoredPlugins;
    	$properties['yandex_cityId'] = $this->yandex_cityId;
    	$properties['rp5_cityId'] = $this->rp5_cityId;
    	$properties['gismeteo_cityId'] = $this->gismeteo_cityId;
    	$properties['gismeteo_cityNames'] = $this->gismeteo_cityNames;
    	$properties['addInfoType'] = $this->addInfoType;
    	$this->write($properties);
    }
    
    public function write($properties) {
    	$data = "";
    	$first = true;
    	foreach ($properties as $key => $value) {
    		if ($first) {
    			$first = false;
    		} else {
    			$data .= "\n";
    		}
    		$data .= $key." = ".$value;
    	}
    	$file = DuneSystem::$properties['data_dir_path']."/settings.properties";
    	file_put_contents($file, $data);
    }
    
    public function read() {
    	$properties = array();
    	$file = DuneSystem::$properties['data_dir_path']."/settings.properties";
    	if (file_exists($file)) {
	    	$data = file_get_contents($file);
	    	$lines = explode("\n", $data);
	    	foreach ($lines as $line) {
	    		$line = trim($line);
	    		if (strpos($line, "#") !== 0 && strpos($line, "=") !== false) {
	    			list($key, $value) = explode("=", $line);
	    			$properties[trim($key)] = trim($value);
	    		}
	    	}
    	}
    	return $properties;
    }
    
    public function getFixEnabled() {
    	return $this->fix_enabled;
    }
    
    public function setFixEnabled($fix_enabled) {
    	$this->fix_enabled = $fix_enabled;
    	$this->save();
    }
    
    public function getApiKey() {
    	return $this->apiKey;
    }
    
    public function setApiKey($apiKey) {
    	$this->apiKey = $apiKey;
    	$this->save();
    }
    
    public function getWeatherUpdateInterval() {
    	$allowed = array(15, 30, 60, 120, 180, 360);
    	if (!in_array($this->weatherUpdateInterval, $allowed)) {
    		$this->weatherUpdateInterval = 60;
    	}
    	return $this->weatherUpdateInterval;
    }
    
    public function setWeatherUpdateInterval($weatherUpdateInterval) {
    	$this->weatherUpdateInterval = $weatherUpdateInterval;
    	$this->save();
    }
    
    public function getAddInfoType() {
    	$allowed = array('city', 'weekDay');
    	if (!in_array($this->addInfoType, $allowed)) {
    		$this->addInfoType = 'city';
    	}
    	return $this->addInfoType;
    }
    
    public function setAddInfoType($addInfoType) {
    	$this->addInfoType = $addInfoType;
    	$this->save();
    }
    
    public function getShowMemInfo() {
    	return $this->showMemInfo;
    }
    
    public function setShowMemInfo($showMemInfo) {
    	$this->showMemInfo = $showMemInfo;
    	$this->save();
    }
    
    public function getCleanMemoryThreshold() {
    	return $this->cleanMemoryThreshold;
    }
    
    public function setCleanMemoryThreshold($cleanMemoryThreshold) {
    	$this->cleanMemoryThreshold = $cleanMemoryThreshold;
    	$this->save();
    }
    
    public function getIgnoredPlugins() {
    	return $this->ignoredPlugins;
    }
    
    public function setIgnoredPlugins($ignoredPlugins) {
    	$this->ignoredPlugins = $ignoredPlugins;
    	$this->save();
    }
    
    public function getYandexCityId() {
    	return $this->yandex_cityId;
    }
    
    public function setYandexCityId($yandex_cityId) {
    	$this->yandex_cityId = $yandex_cityId;
    	$this->save();
    }
    
    public function getRp5CityId() {
    	return $this->rp5_cityId;
    }
    
    public function setRp5CityId($rp5_cityId) {
    	$this->rp5_cityId = $rp5_cityId;
    	$this->save();
    }
    
    public function getGismeteoCityId() {
    	return $this->gismeteo_cityId;
    }
    
    public function setGismeteoCityId($gismeteo_cityId) {
    	$this->gismeteo_cityId = $gismeteo_cityId;
    	$this->save();
    }
    
    public function getGismeteoCityNames() {
        return $this->gismeteo_cityNames;
    }
    
    public function setGismeteoCityNames($gismeteo_cityNames) {
        $this->gismeteo_cityNames = $gismeteo_cityNames;
        $this->save();
    }
    
    public function getGismeteoCityName($lang) {
        $cityNames = self::stringToArray($this->getGismeteoCityNames());
        $cityName = "";
        if (isset($cityNames[$lang])) {
            $cityName = $cityNames[$lang];
        }
        if (!$cityName) {
            if (isset($cityNames['en'])) {
                $cityName = $cityNames['en'];
            }
        }
        if (!$cityName) {
            $cityName = $this->getGismeteoCityId();
        }
        return $cityName;
    }
    
    public static function arrayToString($array) {
        $str = "";
        if (is_array($array)) {
            foreach ($array as $key => $value) {
                if ($str) {
                    $str .= "|";
                }
                $str .= $key.":".$value;
            }
        }
        return $str;
    }
        
    public static function stringToArray($str) {
        $array = array();
        if ($str) {
            $entries = explode('|', $str);
            foreach ($entries as $entry) {
                $entryArr = explode(':', $entry, 2);
                $array[$entryArr[0]] = $entryArr[1];
            }
        }
        return $array;
    }
    
}
?>
